@@ -92,6 +92,10 @@ use controller_infra::*;
 use sample_controllers::*;
 use view_controllers::*;
 
+use common::open_source_shim;
+
+open_source_shim!();
+
 pub use controller_infra::{event_to_string, str_to_event};
 
 use std::collections::HashMap;
@@ -118,6 +122,8 @@ make_controllers!(
     Cgroup: CgroupView,
     System: SystemView,
     Zoom: ZoomView,
+    Fold: FoldProcessView,
     NextPage: NextPageImpl,
     PrevPage: PrevPageImpl,
+    Url: URLPopup,
 );
