@@ -23,7 +23,7 @@ use std::rc::Rc;
 use crate::controllers::{event_to_string, Controllers};
 use crate::tab_view::TabView;
 
-struct ControllerHelper {
+pub struct ControllerHelper {
     event: Event,
     description: &'static str,
     cmd: &'static str,
@@ -80,8 +80,10 @@ fn get_description(controller: &Controllers) -> &'static str {
         Controllers::Cgroup => "Show cgroup view.",
         Controllers::System => "Show system core view.",
         Controllers::Zoom => "Zoom into process view filtered by selected cgroup.",
+        Controllers::Fold => "Fold processes (post filter) and display aggregated values.",
         Controllers::NextPage => "scroll down 15 lines primary display.",
         Controllers::PrevPage => "scroll up 15 lines primary display.",
+        Controllers::Url => "Show Corresponding Below Web URL",
         _ => "Unknown",
     }
 }
@@ -133,7 +135,7 @@ fn fill_controllers(
 
     // Unwrap in this vec! must be sccuess, otherwise we may have lost controller(s) and should be detected
     // by unit test.
-    let controllers = vec![
+    let mut controllers = vec![
         cmd_map.get(&Controllers::Help).unwrap().to_string(),
         cmd_map.get(&Controllers::CmdPalette).unwrap().to_string(),
         cmd_map.get(&Controllers::Quit).unwrap().to_string(),
@@ -152,6 +154,7 @@ fn fill_controllers(
         cmd_map.get(&Controllers::Filter).unwrap().to_string(),
         cmd_map.get(&Controllers::CFilter).unwrap().to_string(),
         cmd_map.get(&Controllers::Zoom).unwrap().to_string(),
+        cmd_map.get(&Controllers::Fold).unwrap().to_string(),
         cmd_map.get(&Controllers::Process).unwrap().to_string(),
         cmd_map.get(&Controllers::Cgroup).unwrap().to_string(),
         cmd_map.get(&Controllers::System).unwrap().to_string(),
@@ -159,6 +162,8 @@ fn fill_controllers(
         cmd_map.get(&Controllers::PrevPage).unwrap().to_string(),
     ];
 
+    controllers.extend(crate::get_extra_controller_str(&cmd_map));
+
     v.add_all_str(controllers);
 }
 
